@@ -4,7 +4,7 @@ use Carp ();
 ############################################################################
 package Net::OpenID::Association;
 BEGIN {
-  $Net::OpenID::Association::VERSION = '1.030099_004';
+  $Net::OpenID::Association::VERSION = '1.030099_005';
 }
 use fields (
             'server',    # author-identity identity server endpoint
@@ -17,6 +17,7 @@ use fields (
 use Storable ();
 use Digest::SHA1 qw(sha1);
 use Net::OpenID::Common;
+use URI::Escape qw(uri_escape);
 
 sub new {
     my Net::OpenID::Association $self = shift;
@@ -115,7 +116,7 @@ sub server_assoc {
 
     my $req = HTTP::Request->new(POST => $server);
     $req->header("Content-Type" => "application/x-www-form-urlencoded");
-    $req->content(join("&", map { "$_=" . OpenID::util::eurl($post{$_}) } keys %post));
+    $req->content(join("&", map { "$_=" . uri_escape($post{$_}) } keys %post));
 
     $csr->_debug("Associate mode request: " . $req->content);
 
@@ -228,7 +229,7 @@ Net::OpenID::Association - A relationship with an identity server
 
 =head1 VERSION
 
-version 1.030099_004
+version 1.030099_005
 
 =head1 DESCRIPTION
 
