@@ -4,11 +4,12 @@ use strict;
 use Carp ();
 use LWP::UserAgent;
 use Storable;
+use JSON qw(encode_json);
 
 ############################################################################
 package Net::OpenID::Consumer;
 BEGIN {
-  $Net::OpenID::Consumer::VERSION = '1.030099_004';
+  $Net::OpenID::Consumer::VERSION = '1.030099_005';
 }
 
 use fields (
@@ -192,7 +193,7 @@ sub _fail {
 
 sub json_err {
     my Net::OpenID::Consumer $self = shift;
-    return OpenID::util::js_dumper({
+    return encode_json({
         err_code => $self->{last_errcode},
         err_text => $self->{last_errtext},
     });
@@ -855,7 +856,7 @@ sub verified_identity {
 
         my $req = HTTP::Request->new(POST => $server);
         $req->header("Content-Type" => "application/x-www-form-urlencoded");
-        $req->content(join("&", map { "$_=" . OpenID::util::eurl($post{$_}) } keys %post));
+        $req->content(join("&", map { "$_=" . uri_escape($post{$_}) } keys %post));
 
         my $ua  = $self->ua;
         my $res = $ua->request($req);
@@ -915,7 +916,7 @@ Net::OpenID::Consumer - Library for consumers of OpenID identities
 
 =head1 VERSION
 
-version 1.030099_004
+version 1.030099_005
 
 =head1 SYNOPSIS
 
